/*
 * @Author: zc
 * @Description:
 * @version: 
 * @Date: 2022-08-09 16:19:57
 * @LastEditors: Please set LastEditors
 * @LastEditTime: 2022-11-08 15:59:43
 */
import axios, {AxiosInstance, AxiosResponse} from 'axios';
import { ElMessage, ElMessageBox } from 'element-plus';
import { Session } from '/@/utils/storage';
//exception log
import { Exceptionless } from "@exceptionless/browser";
// 全局配置
import appConfig from "/@/utils/appConfig";

// 配置新建一个 axios 实例
const service:AxiosInstance = axios.create({
	baseURL: appConfig.apiUrl,
	timeout: 50000,
	headers: { 'Content-Type': 'application/json' },
});
// 添加请求拦截器
service.interceptors.request.use(
	(config:any) => {
		// 在发送请求之前做些什么 token
		if (Session.get('token')) {
			(<any>config.headers).common['Authorization'] = `Bearer ${Session.get('token')}`;
		}
		return config;
	},
	async (error) => {
		// 对请求错误做些什么
		let errorText = `${error.message},errUrl:${error.request.responseURL}`;
		// 向追踪服务报告错误
		if(appConfig.sendLog) await Exceptionless.submitException(new Error(errorText));
		return Promise.reject(error);
	}
);

// 添加响应拦截器
service.interceptors.response.use(
	(response:AxiosResponse): any => {
		// 对响应数据做点什么
		const res = response.data;
		if (res.code && res.code !== 0) {
			// `token` 过期或者账号已在别处登录
			if (res.code === 401 || res.code === 4001) {
				//获取页面所有已经存在的提示
				let dom = document.getElementsByClassName('is-message-box');
				if(dom.length === 0){// 解决重复提示的问题
					ElMessageBox.alert('你已被登出，请重新登录', '提示', {type: 'warning'}).then(() => {
						Session.clear(); // 清除浏览器全部临时缓存
						window.location.href = '/'; // 去登录页
					}).catch((): void => {});
				}
			}
			return Promise.reject(service.interceptors.response);
		} else {
			return response.data;
		}
	},
	async (error:any): Promise<never> => {
		let errorText = `${error.message},errUrl:${error.request.responseURL}`;
		// 向追踪服务报告错误
		if(appConfig.sendLog) await Exceptionless.submitException(new Error(errorText));
		// 对响应错误做点什么
		if (error.message.indexOf('timeout') != -1) {
			ElMessage.error('网络超时');
		} else if (error.message == 'Network Error') {
			ElMessage.error('网络连接错误');
		} else if(error.response.status == 401){ //`token` 过期或者账号已在别处登录
				//获取页面所有已经存在的提示
				let dom = document.getElementsByClassName('is-message-box');
				if(dom.length === 0){// 解决重复提示的问题
					ElMessageBox.alert('你已被登出，请重新登录', '提示', {type: 'warning'}).then(() => {
						Session.clear(); // 清除浏览器全部临时缓存
						window.location.href = '/'; // 去登录页
					}).catch((): void => {});
				}
		}else{
			if (error.response.data){
				ElMessage.error(error.response.data.error);
			} else ElMessage.error('接口路径找不到');
		}
		return Promise.reject(error);
	}
);

// 导出 axios 实例
export default service;
