/*
 * @Author: zc
 * @Description: 
 * @version: 
 * @Date: 2022-10-21 09:01:23
 * @LastEditors: Please set LastEditors
 * @LastEditTime: 2022-10-25 16:45:06
 */
// 官方文档：https://docs.microsoft.com/zh-cn/aspnet/core/signalr/javascript-client?view=aspnetcore-6.0&viewFallbackFrom=aspnetcore-2.2&tabs=visual-studio
import * as signalR from '@microsoft/signalr'
import { ElNotification } from 'element-plus'
import { Session } from '/@/utils/storage';
export default {
  // signalR对象
  SR: null as any,
  // 失败连接重试次数
  failNum: 4,
  baseUrl: '',
  init(url:string) {
    const token = Session.get("token")
    const connection = new signalR.HubConnectionBuilder()
      .withUrl(url, { accessTokenFactory:() => token,skipNegotiation: true, transport : 1 })
      .withAutomaticReconnect() //自动重新连接
      .configureLogging(signalR.LogLevel.Warning)
      .build();
    
    this.SR= connection;
    // 断线重连
    connection.onclose(async () => {
      console.log('断开连接了')
      console.assert(connection.state === signalR.HubConnectionState.Disconnected);
      // 建议用户重新刷新浏览器
      await this.start()
    })

    connection.onreconnected(() => {
      console.log('断线重新连接成功')
    })
    this.receiveMsg(connection)
    // 启动
    // this.start();
  },
  /**
   * 调用 this.signalR.start().then(async () => { await this.SR.invoke("method")})
   * @returns 
   */
  async start() {
    const that = this

    try {
      //使用async和await 或 promise的then 和catch 处理来自服务端的异常
      await this.SR.start()
      //console.assert(this.SR.state === signalR.HubConnectionState.Connected);
      console.log('signalR', this.SR.state,'链接状态');
      return true
    } catch (error){
      that.failNum--;
      // console.log(`失败重试剩余次数${that.failNum}`, error)
      if (that.failNum > 0 && this.SR.state.Disconnected) {
        setTimeout(async () => {
          await this.SR.start()
        }, 5000)
      }
      return false
    }
  },
  // 接收消息处理
  receiveMsg(connection:any) {
    // 接收欢迎语
    // connection.on("Ring", (data:any) => {
    //   console.log(data)
    // });
    // 接收后台手动推送消息
    connection.on("receiveNotice", (title:string, data:any) => {
      ElNotification({
        type: 'info',
        title: title,
        message: data,
        dangerouslyUseHTMLString: true,
        duration: 0
      })
    //   webNotify({ title: title, body: data })
    console.log(title,data)
    })
  }
}